@@ -36,7 +36,6 @@ class BaseClassificationDatabasePacker(object):
 
     def __init__(self, source=None, destination=None, progress_bar=False):
         self.source = source
-        self.destination = destination
         self.meta_data = {
             'packed': datetime.now().strftime('%c'),
             'sdk_version': rebotics_sdk.__version__,
@@ -44,8 +43,15 @@ class BaseClassificationDatabasePacker(object):
         }
         self.images = []
 
-        if self.destination is None:
+        if destination is None:
             self.destination = BytesIO()
+        elif isinstance(destination, str) or isinstance(destination, pathlib.PurePath):
+            # in python 2 it doesn't accept pathlib PurePath, but only os.path or str
+            self.destination = str(destination)
+        else:
+            # don't change if we don't know the type
+            self.destination = destination
+
         self.progress_bar = progress_bar
 
     def read_lines(self, lines):
@@ -67,7 +73,7 @@ class BaseClassificationDatabasePacker(object):
         for compression_option in [zipfile.ZIP_DEFLATED, zipfile.ZIP_STORED]:
             try:
                 params['compression'] = compression_option
-                return zipfile.ZipFile(str(file), **params)
+                return zipfile.ZipFile(file, **params)
             except RuntimeError:
                 pass
 
