@@ -10,6 +10,7 @@ from pathlib import Path
 
 import click
 import pandas as pd
+from tqdm import tqdm
 
 from rebotics_sdk import utils
 from rebotics_sdk.advanced.reverse_planogram import make_planogram_df
@@ -18,7 +19,8 @@ from .renderers import format_processing_action_output, format_full_table
 from .tasks import task_create_processing_action_for_image, upload_preview_task, \
     task_download_processing_action, task_recalculate_processing, task_cancel_processing, task_requeue_processing
 from .utils import ReboticsCLIContext, pass_rebotics_context, app_dir, process_role, read_saved_role, task_runner, \
-    download_file_from_dict
+    download_file_from_dict, guess_input_type
+from ..advanced import remote_loaders
 from ..providers import RetailerProvider, ProviderHTTPClientException
 from ..utils import mkdir_p, get_filename_from_url, download_file
 
@@ -478,6 +480,56 @@ def user_subscribe(ctx, username, store, aisle, section):
     ))
 
 
+def task_upload_and_notify_request(task_def):
+    with open(task_def['filepath'], 'rb') as file_io:
+        response = remote_loaders.upload(task_def['destination'], file_io)
+    status_code = response.status_code
+
+    if 200 <= status_code < 300:
+        ctx = task_def['ctx']
+        ctx.provider.notify_processing_upload_finished(task_def['id'])
+        return task_def['id']
+    return None
+
+
+@api.command()
+@click.argument('files', nargs=-1, required=True, type=click.Path(exists=True, dir_okay=False))
+@click.option('-c', '--concurrency', type=int, default=4)
+@click.option('-t', '--input_type')
+@pass_rebotics_context
+def upload_processing_files(ctx, files, concurrency, input_type):
+
+    task_defs = []
+
+    for file in tqdm(files, 'Getting S3 pre-signed post', leave=False):
+        filepath = Path(file)
+        if input_type is None:
+            input_type = guess_input_type(filepath.suffix)
+
+        req = ctx.provider.processing_upload_request(filepath.name, input_type)
+        task_defs.append({
+            'destination': req['destination'],
+            'id': req['id'],
+            'filepath': file,
+            'ctx': ctx,
+        })
+
+    pool = Pool(concurrency if concurrency >= len(task_defs) else len(task_defs))
+    uploaded = []
+
+    for id_ in tqdm(
+        pool.imap_unordered(task_upload_and_notify_request, task_defs),
+        'Uploading files', total=len(task_defs), leave=False
+    ):
+        if id_ is not None:
+            uploaded.append(id_)
+
+    click.echo("Uploaded: {}".format(uploaded))
+    click.echo("Failed: {}".format(list(
+        set(t['id'] for t in task_defs) - set(uploaded)
+    )))
+
+
 @api.group(invoke_without_command=True)
 @click.argument('processing_id', required=True, type=click.STRING)
 @pass_rebotics_context
