@@ -159,6 +159,19 @@ class RetailerProvider(ReboticsBaseProvider):
             }
         )
 
+    @remote_service('/api/v4/processing/upload/request/')
+    def processing_upload_request(self, filename, input_type='image', **kwargs):
+        return self.session.post(
+            json={
+                'filename': filename,
+                'input_type': input_type
+            }
+        )
+
+    @remote_service('/api/v4/processing/upload/request/{id}/finish/')
+    def notify_processing_upload_finished(self, id_):
+        return self.session.post(id=id_)
+
     @remote_service('/api/v4/export/products/')
     def export_products(self, products_filter=None, page=1):
         params = {
